# bk_db_tools (Bam Kaplam's Database Tools)
bk_db_tools is a set of tools to very rapidly, and with a minimum of effort, work with a relational database.

Built around:
* a relational database (sqlite, possibly others.)
* python
* .xlsx files (spreadsheets)

bk_db_tools is a hack! That said, it is one of **the fastest** ways to setup a complete database solution. Including _repeatable_ imports and exports, table creation, table pre population, data editing, and reporting.

Further documentation can be found on the [wiki](https://github.com/SunnysideAaron/bk_db_tools/wiki).

